@@ -81,8 +81,6 @@ void TestDragAndDrop::init()
     m_seatInterface = new SeatInterface(m_display, m_display);
     m_seatInterface->setHasPointer(true);
     m_seatInterface->setHasTouch(true);
-    m_seatInterface->create();
-    QVERIFY(m_seatInterface->isValid());
     m_dataDeviceManagerInterface = new DataDeviceManagerInterface(m_display, m_display);
     m_display->createShm();
 
@@ -208,7 +206,8 @@ void TestDragAndDrop::testPointerDragAndDrop()
     QVERIFY(buttonPressSpy.isValid());
     m_seatInterface->setFocusedPointerSurface(serverSurface);
     m_seatInterface->setTimestamp(2);
-    m_seatInterface->pointerButtonPressed(1);
+    m_seatInterface->notifyPointerButton(1, PointerButtonState::Pressed);
+    m_seatInterface->notifyPointerFrame();
     QVERIFY(buttonPressSpy.wait());
     QCOMPARE(buttonPressSpy.first().at(1).value<quint32>(), quint32(2));
 
@@ -255,7 +254,8 @@ void TestDragAndDrop::testPointerDragAndDrop()
 
     // simulate motion
     m_seatInterface->setTimestamp(3);
-    m_seatInterface->setPointerPos(QPointF(3, 3));
+    m_seatInterface->notifyPointerMotion(QPointF(3, 3));
+    m_seatInterface->notifyPointerFrame();
     QVERIFY(dragMotionSpy.wait());
     QCOMPARE(dragMotionSpy.count(), 1);
     QCOMPARE(dragMotionSpy.first().first().toPointF(), QPointF(3, 3));
@@ -267,7 +267,8 @@ void TestDragAndDrop::testPointerDragAndDrop()
     QSignalSpy droppedSpy(m_dataDevice, &DataDevice::dropped);
     QVERIFY(droppedSpy.isValid());
     m_seatInterface->setTimestamp(4);
-    m_seatInterface->pointerButtonReleased(1);
+    m_seatInterface->notifyPointerButton(1, PointerButtonState::Released);
+    m_seatInterface->notifyPointerFrame();
     QVERIFY(sourceDropSpy.isEmpty());
     QVERIFY(droppedSpy.wait());
     QCOMPARE(sourceDropSpy.count(), 1);
@@ -305,7 +306,8 @@ void TestDragAndDrop::testTouchDragAndDrop()
     QVERIFY(pointAddedSpy.isValid());
     m_seatInterface->setFocusedTouchSurface(serverSurface);
     m_seatInterface->setTimestamp(2);
-    const qint32 touchId = m_seatInterface->touchDown(QPointF(50,50));
+    const qint32 touchId = 0;
+    m_seatInterface->notifyTouchDown(touchId, QPointF(50,50));
     QVERIFY(sequenceStartedSpy.wait());
 
     QScopedPointer<TouchPoint> tp(sequenceStartedSpy.first().at(0).value<TouchPoint*>());
@@ -355,7 +357,7 @@ void TestDragAndDrop::testTouchDragAndDrop()
 
     // simulate motion
     m_seatInterface->setTimestamp(3);
-    m_seatInterface->touchMove(touchId, QPointF(75, 75));
+    m_seatInterface->notifyTouchMotion(touchId, QPointF(75, 75));
     QVERIFY(dragMotionSpy.wait());
     QCOMPARE(dragMotionSpy.count(), 1);
     QCOMPARE(dragMotionSpy.first().first().toPointF(), QPointF(75, 75));
@@ -367,7 +369,7 @@ void TestDragAndDrop::testTouchDragAndDrop()
     QSignalSpy droppedSpy(m_dataDevice, &DataDevice::dropped);
     QVERIFY(droppedSpy.isValid());
     m_seatInterface->setTimestamp(4);
-    m_seatInterface->touchUp(touchId);
+    m_seatInterface->notifyTouchUp(touchId);
     QVERIFY(sourceDropSpy.isEmpty());
     QVERIFY(droppedSpy.wait());
     QCOMPARE(sourceDropSpy.count(), 1);
@@ -403,7 +405,8 @@ void TestDragAndDrop::testDragAndDropWithCancelByDestroyDataSource()
     QVERIFY(buttonPressSpy.isValid());
     m_seatInterface->setFocusedPointerSurface(serverSurface);
     m_seatInterface->setTimestamp(2);
-    m_seatInterface->pointerButtonPressed(1);
+    m_seatInterface->notifyPointerButton(1, PointerButtonState::Pressed);
+    m_seatInterface->notifyPointerFrame();
     QVERIFY(buttonPressSpy.wait());
     QCOMPARE(buttonPressSpy.first().at(1).value<quint32>(), quint32(2));
 
@@ -450,7 +453,8 @@ void TestDragAndDrop::testDragAndDropWithCancelByDestroyDataSource()
 
     // simulate motion
     m_seatInterface->setTimestamp(3);
-    m_seatInterface->setPointerPos(QPointF(3, 3));
+    m_seatInterface->notifyPointerMotion(QPointF(3, 3));
+    m_seatInterface->notifyPointerFrame();
     QVERIFY(dragMotionSpy.wait());
     QCOMPARE(dragMotionSpy.count(), 1);
     QCOMPARE(dragMotionSpy.first().first().toPointF(), QPointF(3, 3));
@@ -470,7 +474,8 @@ void TestDragAndDrop::testDragAndDropWithCancelByDestroyDataSource()
     QSignalSpy droppedSpy(m_dataDevice, &DataDevice::dropped);
     QVERIFY(droppedSpy.isValid());
     m_seatInterface->setTimestamp(4);
-    m_seatInterface->pointerButtonReleased(1);
+    m_seatInterface->notifyPointerButton(1, PointerButtonState::Released);
+    m_seatInterface->notifyPointerFrame();
     QVERIFY(!droppedSpy.wait(500));
 
     // verify that we did not get any further input events
@@ -508,9 +513,10 @@ void TestDragAndDrop::testPointerEventsIgnored()
     // first simulate a few things
     quint32 timestamp = 1;
     m_seatInterface->setTimestamp(timestamp++);
-    m_seatInterface->setPointerPos(QPointF(10, 10));
+    m_seatInterface->notifyPointerMotion(QPointF(10, 10));
     m_seatInterface->setTimestamp(timestamp++);
-    m_seatInterface->pointerAxis(Qt::Vertical, 5);
+    m_seatInterface->notifyPointerAxis(Qt::Vertical, 5, 1, PointerAxisSource::Wheel);
+    m_seatInterface->notifyPointerFrame();
     // verify that we have those
     QVERIFY(axisSpy.wait());
     QCOMPARE(axisSpy.count(), 1);
@@ -521,7 +527,8 @@ void TestDragAndDrop::testPointerEventsIgnored()
 
     // let's start the drag
     m_seatInterface->setTimestamp(timestamp++);
-    m_seatInterface->pointerButtonPressed(1);
+    m_seatInterface->notifyPointerButton(1, PointerButtonState::Pressed);
+    m_seatInterface->notifyPointerFrame();
     QVERIFY(buttonSpy.wait());
     QCOMPARE(buttonSpy.count(), 1);
     m_dataDevice->startDrag(buttonSpy.first().first().value<quint32>(), m_dataSource, s.data());
@@ -529,25 +536,33 @@ void TestDragAndDrop::testPointerEventsIgnored()
 
     // now simulate all the possible pointer interactions
     m_seatInterface->setTimestamp(timestamp++);
-    m_seatInterface->pointerButtonPressed(2);
+    m_seatInterface->notifyPointerButton(2, PointerButtonState::Pressed);
+    m_seatInterface->notifyPointerFrame();
     m_seatInterface->setTimestamp(timestamp++);
-    m_seatInterface->pointerButtonReleased(2);
+    m_seatInterface->notifyPointerButton(2, PointerButtonState::Released);
+    m_seatInterface->notifyPointerFrame();
     m_seatInterface->setTimestamp(timestamp++);
-    m_seatInterface->pointerAxis(Qt::Vertical, 5);
+    m_seatInterface->notifyPointerAxis(Qt::Vertical, 5, 1, PointerAxisSource::Wheel);
+    m_seatInterface->notifyPointerFrame();
     m_seatInterface->setTimestamp(timestamp++);
-    m_seatInterface->pointerAxis(Qt::Horizontal, 5);
+    m_seatInterface->notifyPointerAxis(Qt::Vertical, 5, 1, PointerAxisSource::Wheel);
+    m_seatInterface->notifyPointerFrame();
     m_seatInterface->setTimestamp(timestamp++);
     m_seatInterface->setFocusedPointerSurface(nullptr);
+    m_seatInterface->notifyPointerFrame();
     m_seatInterface->setTimestamp(timestamp++);
     m_seatInterface->setFocusedPointerSurface(serverSurface);
+    m_seatInterface->notifyPointerFrame();
     m_seatInterface->setTimestamp(timestamp++);
-    m_seatInterface->setPointerPos(QPointF(50, 50));
+    m_seatInterface->notifyPointerMotion(QPointF(50, 50));
+    m_seatInterface->notifyPointerFrame();
 
     // last but not least, simulate the drop
     QSignalSpy cancelledSpy(m_dataSource, &DataSource::cancelled);
     QVERIFY(cancelledSpy.isValid());
     m_seatInterface->setTimestamp(timestamp++);
-    m_seatInterface->pointerButtonReleased(1);
+    m_seatInterface->notifyPointerButton(1, PointerButtonState::Released);
+    m_seatInterface->notifyPointerFrame();
     QVERIFY(cancelledSpy.wait());
 
     // all the changes should have been ignored
