@@ -27,7 +27,7 @@ private Q_SLOTS:
     void cleanup();
 
     void testRegistry();
-    void testModeChanges();
+    void testModeChange();
     void testScaleChange();
 
     void testSubPixel_data();
@@ -73,21 +73,15 @@ void TestWaylandOutput::init()
     m_serverOutput = new OutputInterface(m_display, this);
     QCOMPARE(m_serverOutput->pixelSize(), QSize());
     QCOMPARE(m_serverOutput->refreshRate(), 60000);
-    m_serverOutput->addMode(QSize(800, 600), OutputInterface::ModeFlags(OutputInterface::ModeFlag::Preferred));
-    QCOMPARE(m_serverOutput->pixelSize(), QSize(800, 600));
-    m_serverOutput->addMode(QSize(1024, 768));
-    m_serverOutput->addMode(QSize(1280, 1024), OutputInterface::ModeFlags(), 90000);
-    QCOMPARE(m_serverOutput->pixelSize(), QSize(800, 600));
-    m_serverOutput->setCurrentMode(QSize(1024, 768));
+    m_serverOutput->setMode(QSize(1024, 768));
     QCOMPARE(m_serverOutput->pixelSize(), QSize(1024, 768));
     QCOMPARE(m_serverOutput->refreshRate(), 60000);
-    m_serverOutput->create();
     QCOMPARE(m_serverOutput->isDpmsSupported(), false);
     QCOMPARE(m_serverOutput->dpmsMode(), OutputInterface::DpmsMode::Off);
 
     // setup connection
     m_connection = new KWayland::Client::ConnectionThread;
-    QSignalSpy connectedSpy(m_connection, SIGNAL(connected()));
+    QSignalSpy connectedSpy(m_connection, &KWayland::Client::ConnectionThread::connected);
     m_connection->setSocketName(s_socketName);
 
     m_thread = new QThread(this);
@@ -146,9 +140,10 @@ void TestWaylandOutput::testRegistry()
     // changing again should not trigger signal
     m_serverOutput->setPhysicalSize(QSize(200, 100));
     QCOMPARE(physicalSizeChangedSpy.count(), 1);
+    m_serverOutput->done();
 
     KWayland::Client::Registry registry;
-    QSignalSpy announced(&registry, SIGNAL(outputAnnounced(quint32,quint32)));
+    QSignalSpy announced(&registry, &KWayland::Client::Registry::outputAnnounced);
     registry.create(m_connection->display());
     QVERIFY(registry.isValid());
     registry.setup();
@@ -168,7 +163,7 @@ void TestWaylandOutput::testRegistry()
     QCOMPARE(output.subPixel(), KWayland::Client::Output::SubPixel::Unknown);
     QCOMPARE(output.transform(), KWayland::Client::Output::Transform::Normal);
 
-    QSignalSpy outputChanged(&output, SIGNAL(changed()));
+    QSignalSpy outputChanged(&output, &KWayland::Client::Output::changed);
     QVERIFY(outputChanged.isValid());
 
     auto o = registry.bindOutput(announced.first().first().value<quint32>(), announced.first().last().value<quint32>());
@@ -192,25 +187,11 @@ void TestWaylandOutput::testRegistry()
     QCOMPARE(output.transform(), KWayland::Client::Output::Transform::Normal);
 }
 
-void TestWaylandOutput::testModeChanges()
+void TestWaylandOutput::testModeChange()
 {
-    // verify the server modes
-    using namespace KWaylandServer;
-    const auto serverModes = m_serverOutput->modes();
-    QCOMPARE(serverModes.count(), 3);
-    QCOMPARE(serverModes.at(0).size, QSize(800, 600));
-    QCOMPARE(serverModes.at(1).size, QSize(1024, 768));
-    QCOMPARE(serverModes.at(2).size, QSize(1280, 1024));
-    QCOMPARE(serverModes.at(0).refreshRate, 60000);
-    QCOMPARE(serverModes.at(1).refreshRate, 60000);
-    QCOMPARE(serverModes.at(2).refreshRate, 90000);
-    QCOMPARE(serverModes.at(0).flags, OutputInterface::ModeFlags(OutputInterface::ModeFlag::Preferred));
-    QCOMPARE(serverModes.at(1).flags, OutputInterface::ModeFlags(OutputInterface::ModeFlag::Current));
-    QCOMPARE(serverModes.at(2).flags, OutputInterface::ModeFlags());
-
     using namespace KWayland::Client;
     KWayland::Client::Registry registry;
-    QSignalSpy announced(&registry, SIGNAL(outputAnnounced(quint32,quint32)));
+    QSignalSpy announced(&registry, &KWayland::Client::Registry::outputAnnounced);
     registry.setEventQueue(m_queue);
     registry.create(m_connection->display());
     QVERIFY(registry.isValid());
@@ -219,91 +200,39 @@ void TestWaylandOutput::testModeChanges()
     QVERIFY(announced.wait());
 
     KWayland::Client::Output output;
-    QSignalSpy outputChanged(&output, SIGNAL(changed()));
+    QSignalSpy outputChanged(&output, &KWayland::Client::Output::changed);
     QVERIFY(outputChanged.isValid());
-    QSignalSpy modeAddedSpy(&output, SIGNAL(modeAdded(KWayland::Client::Output::Mode)));
+    QSignalSpy modeAddedSpy(&output, &KWayland::Client::Output::modeAdded);
     QVERIFY(modeAddedSpy.isValid());
     output.setup(registry.bindOutput(announced.first().first().value<quint32>(), announced.first().last().value<quint32>()));
     wl_display_flush(m_connection->display());
     QVERIFY(outputChanged.wait());
-    QCOMPARE(modeAddedSpy.count(), 3);
-    QCOMPARE(modeAddedSpy.at(0).first().value<Output::Mode>().size, QSize(800, 600));
+    QCOMPARE(modeAddedSpy.count(), 1);
+    QCOMPARE(modeAddedSpy.at(0).first().value<Output::Mode>().size, QSize(1024, 768));
     QCOMPARE(modeAddedSpy.at(0).first().value<Output::Mode>().refreshRate, 60000);
-    QCOMPARE(modeAddedSpy.at(0).first().value<Output::Mode>().flags, Output::Mode::Flags(Output::Mode::Flag::Preferred));
+    QCOMPARE(modeAddedSpy.at(0).first().value<Output::Mode>().flags, Output::Mode::Flags(Output::Mode::Flag::Current));
     QCOMPARE(modeAddedSpy.at(0).first().value<Output::Mode>().output, QPointer<Output>(&output));
-    QCOMPARE(modeAddedSpy.at(1).first().value<Output::Mode>().size, QSize(1280, 1024));
-    QCOMPARE(modeAddedSpy.at(1).first().value<Output::Mode>().refreshRate, 90000);
-    QCOMPARE(modeAddedSpy.at(1).first().value<Output::Mode>().flags, Output::Mode::Flags(Output::Mode::Flag::None));
-    QCOMPARE(modeAddedSpy.at(1).first().value<Output::Mode>().output, QPointer<Output>(&output));
-    QCOMPARE(modeAddedSpy.at(2).first().value<Output::Mode>().size, QSize(1024, 768));
-    QCOMPARE(modeAddedSpy.at(2).first().value<Output::Mode>().refreshRate, 60000);
-    QCOMPARE(modeAddedSpy.at(2).first().value<Output::Mode>().flags, Output::Mode::Flags(Output::Mode::Flag::Current));
-    QCOMPARE(modeAddedSpy.at(2).first().value<Output::Mode>().output, QPointer<Output>(&output));
-    const QList<Output::Mode> &modes = output.modes();
-    QCOMPARE(modes.size(), 3);
-    QCOMPARE(modes.at(0), modeAddedSpy.at(0).first().value<Output::Mode>());
-    QCOMPARE(modes.at(1), modeAddedSpy.at(1).first().value<Output::Mode>());
-    QCOMPARE(modes.at(2), modeAddedSpy.at(2).first().value<Output::Mode>());
-
     QCOMPARE(output.pixelSize(), QSize(1024, 768));
-
-    // change the current mode
-    outputChanged.clear();
-    QSignalSpy modeChangedSpy(&output, &KWayland::Client::Output::modeChanged);
-    QVERIFY(modeChangedSpy.isValid());
-    m_serverOutput->setCurrentMode(QSize(800, 600));
-    QVERIFY(modeChangedSpy.wait());
-    if (modeChangedSpy.size() == 1) {
-        QVERIFY(modeChangedSpy.wait());
-    }
-    QCOMPARE(modeChangedSpy.size(), 2);
-    // the one which lost the current flag
-    QCOMPARE(modeChangedSpy.first().first().value<Output::Mode>().size, QSize(1024, 768));
-    QCOMPARE(modeChangedSpy.first().first().value<Output::Mode>().refreshRate, 60000);
-    QCOMPARE(modeChangedSpy.first().first().value<Output::Mode>().flags, Output::Mode::Flags());
-    // the one which got the current flag
-    QCOMPARE(modeChangedSpy.last().first().value<Output::Mode>().size, QSize(800, 600));
-    QCOMPARE(modeChangedSpy.last().first().value<Output::Mode>().refreshRate, 60000);
-    QCOMPARE(modeChangedSpy.last().first().value<Output::Mode>().flags, Output::Mode::Flags(Output::Mode::Flag::Current | Output::Mode::Flag::Preferred));
-    QVERIFY(!outputChanged.isEmpty());
-    QCOMPARE(output.pixelSize(), QSize(800, 600));
-    const QList<Output::Mode> &modes2 = output.modes();
-    QCOMPARE(modes2.at(0).size, QSize(1280, 1024));
-    QCOMPARE(modes2.at(0).refreshRate, 90000);
-    QCOMPARE(modes2.at(0).flags, Output::Mode::Flag::None);
-    QCOMPARE(modes2.at(1).size, QSize(1024, 768));
-    QCOMPARE(modes2.at(1).refreshRate, 60000);
-    QCOMPARE(modes2.at(1).flags, Output::Mode::Flag::None);
-    QCOMPARE(modes2.at(2).size, QSize(800, 600));
-    QCOMPARE(modes2.at(2).refreshRate, 60000);
-    QCOMPARE(modes2.at(2).flags, Output::Mode::Flag::Current | Output::Mode::Flag::Preferred);
+    QCOMPARE(output.refreshRate(), 60000);
 
     // change once more
-    outputChanged.clear();
-    modeChangedSpy.clear();
-    m_serverOutput->setCurrentMode(QSize(1280, 1024), 90000);
+    m_serverOutput->setMode(QSize(1280, 1024), 90000);
     QCOMPARE(m_serverOutput->refreshRate(), 90000);
-    QVERIFY(modeChangedSpy.wait());
-    if (modeChangedSpy.size() == 1) {
-        QVERIFY(modeChangedSpy.wait());
-    }
-    QCOMPARE(modeChangedSpy.size(), 2);
-    // the one which lost the current flag
-    QCOMPARE(modeChangedSpy.first().first().value<Output::Mode>().size, QSize(800, 600));
-    QCOMPARE(modeChangedSpy.first().first().value<Output::Mode>().refreshRate, 60000);
-    QCOMPARE(modeChangedSpy.first().first().value<Output::Mode>().flags, Output::Mode::Flags(Output::Mode::Flag::Preferred));
-    // the one which got the current flag
-    QCOMPARE(modeChangedSpy.last().first().value<Output::Mode>().size, QSize(1280, 1024));
-    QCOMPARE(modeChangedSpy.last().first().value<Output::Mode>().refreshRate, 90000);
-    QCOMPARE(modeChangedSpy.last().first().value<Output::Mode>().flags, Output::Mode::Flags(Output::Mode::Flag::Current));
-    QVERIFY(!outputChanged.isEmpty());
+    m_serverOutput->done();
+    QVERIFY(outputChanged.wait());
+    QCOMPARE(modeAddedSpy.count(), 2);
+    QCOMPARE(modeAddedSpy.at(1).first().value<Output::Mode>().size, QSize(1280, 1024));
+    QCOMPARE(modeAddedSpy.at(1).first().value<Output::Mode>().refreshRate, 90000);
+    QCOMPARE(modeAddedSpy.at(1).first().value<Output::Mode>().flags, Output::Mode::Flags(Output::Mode::Flag::Current));
+    QCOMPARE(modeAddedSpy.at(1).first().value<Output::Mode>().output, QPointer<Output>(&output));
     QCOMPARE(output.pixelSize(), QSize(1280, 1024));
+    QCOMPARE(output.refreshRate(), 90000);
 }
 
 void TestWaylandOutput::testScaleChange()
 {
     KWayland::Client::Registry registry;
-    QSignalSpy announced(&registry, SIGNAL(outputAnnounced(quint32,quint32)));
+    QSignalSpy announced(&registry, &KWayland::Client::Registry::outputAnnounced);
     registry.create(m_connection->display());
     QVERIFY(registry.isValid());
     registry.setup();
@@ -311,7 +240,7 @@ void TestWaylandOutput::testScaleChange()
     QVERIFY(announced.wait());
 
     KWayland::Client::Output output;
-    QSignalSpy outputChanged(&output, SIGNAL(changed()));
+    QSignalSpy outputChanged(&output, &KWayland::Client::Output::changed);
     QVERIFY(outputChanged.isValid());
     output.setup(registry.bindOutput(announced.first().first().value<quint32>(), announced.first().last().value<quint32>()));
     wl_display_flush(m_connection->display());
@@ -325,6 +254,7 @@ void TestWaylandOutput::testScaleChange()
     QVERIFY(serverScaleChanged.isValid());
     m_serverOutput->setScale(2);
     QCOMPARE(m_serverOutput->scale(), 2);
+    m_serverOutput->done();
     QCOMPARE(serverScaleChanged.count(), 1);
     QVERIFY(outputChanged.wait());
     QCOMPARE(output.scale(), 2);
@@ -336,6 +266,7 @@ void TestWaylandOutput::testScaleChange()
     // change once more
     outputChanged.clear();
     m_serverOutput->setScale(4);
+    m_serverOutput->done();
     QVERIFY(outputChanged.wait());
     QCOMPARE(output.scale(), 4);
 }
@@ -370,7 +301,7 @@ void TestWaylandOutput::testSubPixel()
     QCOMPARE(serverSubPixelChangedSpy.count(), 1);
 
     KWayland::Client::Registry registry;
-    QSignalSpy announced(&registry, SIGNAL(outputAnnounced(quint32,quint32)));
+    QSignalSpy announced(&registry, &KWayland::Client::Registry::outputAnnounced);
     registry.create(m_connection->display());
     QVERIFY(registry.isValid());
     registry.setup();
@@ -378,7 +309,7 @@ void TestWaylandOutput::testSubPixel()
     QVERIFY(announced.wait());
 
     KWayland::Client::Output output;
-    QSignalSpy outputChanged(&output, SIGNAL(changed()));
+    QSignalSpy outputChanged(&output, &KWayland::Client::Output::changed);
     QVERIFY(outputChanged.isValid());
     output.setup(registry.bindOutput(announced.first().first().value<quint32>(), announced.first().last().value<quint32>()));
     wl_display_flush(m_connection->display());
@@ -392,6 +323,7 @@ void TestWaylandOutput::testSubPixel()
     outputChanged.clear();
     m_serverOutput->setSubPixel(OutputInterface::SubPixel::Unknown);
     QCOMPARE(m_serverOutput->subPixel(), OutputInterface::SubPixel::Unknown);
+    m_serverOutput->done();
     QCOMPARE(serverSubPixelChangedSpy.count(), 2);
     if (outputChanged.isEmpty()) {
         QVERIFY(outputChanged.wait());
@@ -431,7 +363,7 @@ void TestWaylandOutput::testTransform()
     QCOMPARE(serverTransformChangedSpy.count(), 1);
 
     KWayland::Client::Registry registry;
-    QSignalSpy announced(&registry, SIGNAL(outputAnnounced(quint32,quint32)));
+    QSignalSpy announced(&registry, &KWayland::Client::Registry::outputAnnounced);
     registry.create(m_connection->display());
     QVERIFY(registry.isValid());
     registry.setup();
@@ -439,7 +371,7 @@ void TestWaylandOutput::testTransform()
     QVERIFY(announced.wait());
 
     KWayland::Client::Output *output = registry.createOutput(announced.first().first().value<quint32>(), announced.first().last().value<quint32>(), &registry);
-    QSignalSpy outputChanged(output, SIGNAL(changed()));
+    QSignalSpy outputChanged(output, &KWayland::Client::Output::changed);
     QVERIFY(outputChanged.isValid());
     wl_display_flush(m_connection->display());
     if (outputChanged.isEmpty()) {
@@ -452,6 +384,7 @@ void TestWaylandOutput::testTransform()
     outputChanged.clear();
     m_serverOutput->setTransform(OutputInterface::Transform::Normal);
     QCOMPARE(m_serverOutput->transform(), OutputInterface::Transform::Normal);
+    m_serverOutput->done();
     QCOMPARE(serverTransformChangedSpy.count(), 2);
     if (outputChanged.isEmpty()) {
         QVERIFY(outputChanged.wait());
@@ -477,7 +410,7 @@ void TestWaylandOutput::testDpms()
     using namespace KWayland::Client;
     using namespace KWaylandServer;
 
-    new DpmsManagerInterface(m_display);
+    DpmsManagerInterface iface(m_display);
 
     // set Dpms on the Output
     QSignalSpy serverDpmsSupportedChangedSpy(m_serverOutput, &OutputInterface::dpmsSupportedChanged);
@@ -572,7 +505,7 @@ void TestWaylandOutput::testDpmsRequestMode()
     using namespace KWaylandServer;
 
     // setup code
-    new DpmsManagerInterface(m_display);
+    DpmsManagerInterface iface(m_display);
 
     // set Dpms on the Output
     QSignalSpy serverDpmsSupportedChangedSpy(m_serverOutput, &OutputInterface::dpmsSupportedChanged);
