@@ -91,7 +91,7 @@ void TestSubSurface::init()
 
     // setup connection
     m_connection = new KWayland::Client::ConnectionThread;
-    QSignalSpy connectedSpy(m_connection, SIGNAL(connected()));
+    QSignalSpy connectedSpy(m_connection, &KWayland::Client::ConnectionThread::connected);
     m_connection->setSocketName(s_socketName);
 
     m_thread = new QThread(this);
@@ -107,9 +107,9 @@ void TestSubSurface::init()
     QVERIFY(m_queue->isValid());
 
     KWayland::Client::Registry registry;
-    QSignalSpy compositorSpy(&registry, SIGNAL(compositorAnnounced(quint32,quint32)));
+    QSignalSpy compositorSpy(&registry, &KWayland::Client::Registry::compositorAnnounced);
     QVERIFY(compositorSpy.isValid());
-    QSignalSpy subCompositorSpy(&registry, SIGNAL(subCompositorAnnounced(quint32,quint32)));
+    QSignalSpy subCompositorSpy(&registry, &KWayland::Client::Registry::subCompositorAnnounced);
     QVERIFY(subCompositorSpy.isValid());
     QVERIFY(!registry.eventQueue());
     registry.setEventQueue(m_queue);
@@ -169,7 +169,7 @@ void TestSubSurface::testCreate()
 {
     using namespace KWayland::Client;
     using namespace KWaylandServer;
-    QSignalSpy surfaceCreatedSpy(m_compositorInterface, SIGNAL(surfaceCreated(KWaylandServer::SurfaceInterface*)));
+    QSignalSpy surfaceCreatedSpy(m_compositorInterface, &KWaylandServer::CompositorInterface::surfaceCreated);
     QVERIFY(surfaceCreatedSpy.isValid());
 
     // create two Surfaces
@@ -184,7 +184,7 @@ void TestSubSurface::testCreate()
     SurfaceInterface *serverParentSurface = surfaceCreatedSpy.first().first().value<KWaylandServer::SurfaceInterface*>();
     QVERIFY(serverParentSurface);
 
-    QSignalSpy subSurfaceCreatedSpy(m_subcompositorInterface, SIGNAL(subSurfaceCreated(KWaylandServer::SubSurfaceInterface*)));
+    QSignalSpy subSurfaceCreatedSpy(m_subcompositorInterface, &KWaylandServer::SubCompositorInterface::subSurfaceCreated);
     QVERIFY(subSurfaceCreatedSpy.isValid());
 
     // create subSurface for surface of parent
@@ -209,7 +209,7 @@ void TestSubSurface::testCreate()
     QCOMPARE(serverParentSurface->childSubSurfaces().first(), serverSubSurface);
 
     // and let's destroy it again
-    QSignalSpy destroyedSpy(serverSubSurface, SIGNAL(destroyed(QObject*)));
+    QSignalSpy destroyedSpy(serverSubSurface, &QObject::destroyed);
     QVERIFY(destroyedSpy.isValid());
     subSurface.reset();
     QVERIFY(destroyedSpy.wait());
@@ -236,7 +236,7 @@ void TestSubSurface::testMode()
     QScopedPointer<Surface> surface(m_compositor->createSurface());
     QScopedPointer<Surface> parent(m_compositor->createSurface());
 
-    QSignalSpy subSurfaceCreatedSpy(m_subcompositorInterface, SIGNAL(subSurfaceCreated(KWaylandServer::SubSurfaceInterface*)));
+    QSignalSpy subSurfaceCreatedSpy(m_subcompositorInterface, &KWaylandServer::SubCompositorInterface::subSurfaceCreated);
     QVERIFY(subSurfaceCreatedSpy.isValid());
 
     // create the SubSurface for surface of parent
@@ -250,7 +250,7 @@ void TestSubSurface::testMode()
     QCOMPARE(serverSubSurface->mode(), SubSurfaceInterface::Mode::Synchronized);
 
     // verify that we can change to desynchronized
-    QSignalSpy modeChangedSpy(serverSubSurface, SIGNAL(modeChanged(KWaylandServer::SubSurfaceInterface::Mode)));
+    QSignalSpy modeChangedSpy(serverSubSurface, &KWaylandServer::SubSurfaceInterface::modeChanged);
     QVERIFY(modeChangedSpy.isValid());
 
     subSurface->setMode(SubSurface::Mode::Desynchronized);
@@ -292,7 +292,7 @@ void TestSubSurface::testPosition()
     QScopedPointer<Surface> surface(m_compositor->createSurface());
     QScopedPointer<Surface> parent(m_compositor->createSurface());
 
-    QSignalSpy subSurfaceCreatedSpy(m_subcompositorInterface, SIGNAL(subSurfaceCreated(KWaylandServer::SubSurfaceInterface*)));
+    QSignalSpy subSurfaceCreatedSpy(m_subcompositorInterface, &KWaylandServer::SubCompositorInterface::subSurfaceCreated);
     QVERIFY(subSurfaceCreatedSpy.isValid());
 
     // create the SubSurface for surface of parent
@@ -301,10 +301,6 @@ void TestSubSurface::testPosition()
     SubSurfaceInterface *serverSubSurface = subSurfaceCreatedSpy.first().first().value<KWaylandServer::SubSurfaceInterface*>();
     QVERIFY(serverSubSurface);
 
-    // create a signalspy
-    QSignalSpy subsurfaceTreeChanged(serverSubSurface->parentSurface(), &SurfaceInterface::subSurfaceTreeChanged);
-    QVERIFY(subsurfaceTreeChanged.isValid());
-
     // put the subsurface in the desired commit mode
     QFETCH(KWayland::Client::SubSurface::Mode, commitMode);
     subSurface->setMode(commitMode);
@@ -313,7 +309,7 @@ void TestSubSurface::testPosition()
     QCOMPARE(subSurface->position(), QPoint());
     QCOMPARE(serverSubSurface->position(), QPoint());
 
-    QSignalSpy positionChangedSpy(serverSubSurface, SIGNAL(positionChanged(QPoint)));
+    QSignalSpy positionChangedSpy(serverSubSurface, &KWaylandServer::SubSurfaceInterface::positionChanged);
     QVERIFY(positionChangedSpy.isValid());
 
     // changing the position should not trigger a direct update on server side
@@ -332,13 +328,13 @@ void TestSubSurface::testPosition()
     QCOMPARE(serverSubSurface->position(), QPoint());
 
     // committing the parent surface should update the position
+    QSignalSpy parentCommittedSpy(serverSubSurface->parentSurface(), &SurfaceInterface::committed);
+    QVERIFY(parentCommittedSpy.isValid());
     parent->commit(Surface::CommitFlag::None);
-    QCOMPARE(subsurfaceTreeChanged.count(), 0);
-    QVERIFY(positionChangedSpy.wait());
+    QVERIFY(parentCommittedSpy.wait());
     QCOMPARE(positionChangedSpy.count(), 1);
     QCOMPARE(positionChangedSpy.first().first().toPoint(), QPoint(20, 30));
     QCOMPARE(serverSubSurface->position(), QPoint(20, 30));
-    QCOMPARE(subsurfaceTreeChanged.count(), 1);
 }
 
 void TestSubSurface::testPlaceAbove()
@@ -351,7 +347,7 @@ void TestSubSurface::testPlaceAbove()
     QScopedPointer<Surface> surface3(m_compositor->createSurface());
     QScopedPointer<Surface> parent(m_compositor->createSurface());
 
-    QSignalSpy subSurfaceCreatedSpy(m_subcompositorInterface, SIGNAL(subSurfaceCreated(KWaylandServer::SubSurfaceInterface*)));
+    QSignalSpy subSurfaceCreatedSpy(m_subcompositorInterface, &KWaylandServer::SubCompositorInterface::subSurfaceCreated);
     QVERIFY(subSurfaceCreatedSpy.isValid());
 
     // create the SubSurfaces for surface of parent
@@ -452,7 +448,7 @@ void TestSubSurface::testPlaceBelow()
     QScopedPointer<Surface> surface3(m_compositor->createSurface());
     QScopedPointer<Surface> parent(m_compositor->createSurface());
 
-    QSignalSpy subSurfaceCreatedSpy(m_subcompositorInterface, SIGNAL(subSurfaceCreated(KWaylandServer::SubSurfaceInterface*)));
+    QSignalSpy subSurfaceCreatedSpy(m_subcompositorInterface, &KWaylandServer::SubCompositorInterface::subSurfaceCreated);
     QVERIFY(subSurfaceCreatedSpy.isValid());
 
     // create the SubSurfaces for surface of parent
@@ -562,7 +558,7 @@ void TestSubSurface::testDestroy()
     connect(m_connection, &ConnectionThread::connectionDied, subSurface.data(), &SubSurface::destroy);
     QVERIFY(subSurface->isValid());
 
-    QSignalSpy connectionDiedSpy(m_connection, SIGNAL(connectionDied()));
+    QSignalSpy connectionDiedSpy(m_connection, &KWayland::Client::ConnectionThread::connectionDied);
     QVERIFY(connectionDiedSpy.isValid());
     delete m_display;
     m_display = nullptr;
@@ -606,12 +602,8 @@ void TestSubSurface::testSyncMode()
     QVERIFY(surfaceCreatedSpy.wait());
     auto parentSurface = surfaceCreatedSpy.last().first().value<SurfaceInterface*>();
     QVERIFY(parentSurface);
-    QSignalSpy subSurfaceTreeChangedSpy(parentSurface, &SurfaceInterface::subSurfaceTreeChanged);
-    QVERIFY(subSurfaceTreeChangedSpy.isValid());
     // create subSurface for surface of parent
     QScopedPointer<SubSurface> subSurface(m_subCompositor->createSubSurface(QPointer<Surface>(surface.data()), QPointer<Surface>(parent.data())));
-    QVERIFY(subSurfaceTreeChangedSpy.wait());
-    QCOMPARE(subSurfaceTreeChangedSpy.count(), 1);
 
     // let's damage the child surface
     QSignalSpy childDamagedSpy(childSurface, &SurfaceInterface::damaged);
@@ -637,7 +629,6 @@ void TestSubSurface::testSyncMode()
     parent->commit();
     QVERIFY(childDamagedSpy.wait());
     QCOMPARE(childDamagedSpy.count(), 1);
-    QCOMPARE(subSurfaceTreeChangedSpy.count(), 2);
     QCOMPARE(childSurface->buffer()->data(), image);
     QCOMPARE(parentSurface->buffer()->data(), image2);
     QVERIFY(childSurface->isMapped());
@@ -668,12 +659,8 @@ void TestSubSurface::testDeSyncMode()
     QVERIFY(surfaceCreatedSpy.wait());
     auto parentSurface = surfaceCreatedSpy.last().first().value<SurfaceInterface*>();
     QVERIFY(parentSurface);
-    QSignalSpy subSurfaceTreeChangedSpy(parentSurface, &SurfaceInterface::subSurfaceTreeChanged);
-    QVERIFY(subSurfaceTreeChangedSpy.isValid());
     // create subSurface for surface of parent
     QScopedPointer<SubSurface> subSurface(m_subCompositor->createSubSurface(QPointer<Surface>(surface.data()), QPointer<Surface>(parent.data())));
-    QVERIFY(subSurfaceTreeChangedSpy.wait());
-    QCOMPARE(subSurfaceTreeChangedSpy.count(), 1);
 
     // let's damage the child surface
     QSignalSpy childDamagedSpy(childSurface, &SurfaceInterface::damaged);
@@ -693,7 +680,6 @@ void TestSubSurface::testDeSyncMode()
     // setting to desync should apply the state directly
     subSurface->setMode(SubSurface::Mode::Desynchronized);
     QVERIFY(childDamagedSpy.wait());
-    QCOMPARE(subSurfaceTreeChangedSpy.count(), 2);
     QCOMPARE(childSurface->buffer()->data(), image);
     QVERIFY(!childSurface->isMapped());
     QVERIFY(!parentSurface->isMapped());
@@ -704,7 +690,6 @@ void TestSubSurface::testDeSyncMode()
     surface->damage(QRect(0, 0, 200, 200));
     surface->commit(Surface::CommitFlag::None);
     QVERIFY(childDamagedSpy.wait());
-    QCOMPARE(subSurfaceTreeChangedSpy.count(), 3);
     QCOMPARE(childSurface->buffer()->data(), image);
 }
 
@@ -734,15 +719,14 @@ void TestSubSurface::testMainSurfaceFromTree()
     auto childLevel3ServerSurface = surfaceCreatedSpy.last().first().value<SurfaceInterface*>();
     QVERIFY(childLevel3ServerSurface);
 
-    QSignalSpy subSurfaceTreeChangedSpy(parentServerSurface, &SurfaceInterface::subSurfaceTreeChanged);
-    QVERIFY(subSurfaceTreeChangedSpy.isValid());
-
     m_subCompositor->createSubSurface(childLevel1Surface.data(), parentSurface.data());
     m_subCompositor->createSubSurface(childLevel2Surface.data(), childLevel1Surface.data());
     m_subCompositor->createSubSurface(childLevel3Surface.data(), childLevel2Surface.data());
 
+    QSignalSpy parentCommittedSpy(parentServerSurface, &SurfaceInterface::committed);
+    QVERIFY(parentCommittedSpy.isValid());
     parentSurface->commit(Surface::CommitFlag::None);
-    QVERIFY(subSurfaceTreeChangedSpy.wait());
+    QVERIFY(parentCommittedSpy.wait());
 
     QCOMPARE(parentServerSurface->childSubSurfaces().count(), 1);
     auto child = parentServerSurface->childSubSurfaces().first();
@@ -777,18 +761,18 @@ void TestSubSurface::testRemoveSurface()
     auto childServerSurface = surfaceCreatedSpy.last().first().value<SurfaceInterface*>();
     QVERIFY(childServerSurface);
 
-    QSignalSpy subSurfaceTreeChangedSpy(parentServerSurface, &SurfaceInterface::subSurfaceTreeChanged);
-    QVERIFY(subSurfaceTreeChangedSpy.isValid());
+    QSignalSpy childrenChangedSpy(parentServerSurface, &SurfaceInterface::childSubSurfacesChanged);
+    QVERIFY(childrenChangedSpy.isValid());
 
     m_subCompositor->createSubSurface(childSurface.data(), parentSurface.data());
     parentSurface->commit(Surface::CommitFlag::None);
-    QVERIFY(subSurfaceTreeChangedSpy.wait());
+    QVERIFY(childrenChangedSpy.wait());
 
     QCOMPARE(parentServerSurface->childSubSurfaces().count(), 1);
 
     // destroy surface, takes place immediately
     childSurface.reset();
-    QVERIFY(subSurfaceTreeChangedSpy.wait());
+    QVERIFY(childrenChangedSpy.wait());
     QCOMPARE(parentServerSurface->childSubSurfaces().count(), 0);
 }
 
@@ -817,15 +801,14 @@ void TestSubSurface::testMappingOfSurfaceTree()
     auto childLevel3ServerSurface = surfaceCreatedSpy.last().first().value<SurfaceInterface*>();
     QVERIFY(childLevel3ServerSurface);
 
-    QSignalSpy subSurfaceTreeChangedSpy(parentServerSurface, &SurfaceInterface::subSurfaceTreeChanged);
-    QVERIFY(subSurfaceTreeChangedSpy.isValid());
-
     auto subSurfaceLevel1 = m_subCompositor->createSubSurface(childLevel1Surface.data(), parentSurface.data());
     auto subSurfaceLevel2 = m_subCompositor->createSubSurface(childLevel2Surface.data(), childLevel1Surface.data());
     auto subSurfaceLevel3 = m_subCompositor->createSubSurface(childLevel3Surface.data(), childLevel2Surface.data());
 
+    QSignalSpy parentCommittedSpy(parentServerSurface, &SurfaceInterface::committed);
+    QVERIFY(parentCommittedSpy.isValid());
     parentSurface->commit(Surface::CommitFlag::None);
-    QVERIFY(subSurfaceTreeChangedSpy.wait());
+    QVERIFY(parentCommittedSpy.wait());
 
     QCOMPARE(parentServerSurface->childSubSurfaces().count(), 1);
     auto child = parentServerSurface->childSubSurfaces().first();
@@ -982,6 +965,8 @@ void TestSubSurface::testSurfaceAt()
     childFor1->commit(Surface::CommitFlag::None);
     partImage.fill(Qt::blue);
 
+    QSignalSpy childFor2CommittedSpy(childFor2ServerSurface, &SurfaceInterface::committed);
+    QVERIFY(childFor2CommittedSpy.isValid());
     childFor2->attachBuffer(m_shm->createBuffer(partImage));
     // child for 2's input region is subdivided into quadrants, with input mask on the top left and bottom right
     QRegion region;
@@ -990,10 +975,7 @@ void TestSubSurface::testSurfaceAt()
     childFor2->setInputRegion(m_compositor->createRegion(region).get());
     childFor2->damage(QRect(0, 0, 50, 50));
     childFor2->commit(Surface::CommitFlag::None);
-
-    QSignalSpy treeChangedSpy(parentServerSurface, &SurfaceInterface::subSurfaceTreeChanged);
-    QVERIFY(treeChangedSpy.isValid());
-    QVERIFY(treeChangedSpy.wait());
+    QVERIFY(childFor2CommittedSpy.wait());
 
     QCOMPARE(directChild1ServerSurface->subSurface()->parentSurface(), parentServerSurface);
     QCOMPARE(directChild2ServerSurface->subSurface()->parentSurface(), parentServerSurface);
