@@ -3,10 +3,8 @@
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
-#ifndef WAYLAND_SERVER_EGLSTREAM_CONTROLLER_INTERFACE_H
-#define WAYLAND_SERVER_EGLSTREAM_CONTROLLER_INTERFACE_H
+#pragma once
 
-#include "global.h"
 #include "surface_interface.h"
 
 #include <KWaylandServer/kwaylandserver_export.h>
@@ -45,5 +43,3 @@ private:
 };
 
 }
-
-#endif
